//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//					   (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	PhysicalConstants.h --- simple class holding physical constants
//
//	DESCRIPTION:
//		A simple class providing physical constants of relevance for CAL/OAL
//
//	CHANGE HISTORY:
//		UL, 2000-03-22: 1.0.0: - first version
//		UL, 2000-11-23: 1.1.0: - eVperAo -> eVtimesAo (better name)
//		UL, 2001-03-12: 1.2.0: - added PhysicalConstants::AU
//
//	AUTHOR:
//		U. Lammers, Thu Mar 23 14:38:23 MET 2000
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al., 
//
//	$Header: /home/sasbuild/repositories/sasdev/sas/packages/caloalutils/src/PhysicalConstants.h,v 1.6 2001/03/12 13:49:52 ulammers Exp $
//

#ifndef PHYSICAL_CONSTANTS_H
#define PHYSICAL_CONSTANTS_H

#include "Celestial.h"

class PhysicalConstants {
public:
	//
	//	Ref: Zombeck
	//
	static const double c = 2.99792458e+8,			// speed of light [m/s]
						AU = 1.495978706910000e+11,	// Astronomical Unit [m]
						h = 6.6260755e-34,			// Planck's constant [Js]
						hbar = h/M_TWO_PI,
						Ao = 1.e-10,				// Angstroem [m]
						eVtoJ = 1.60217733e-19,		// J per eV [J/eV]
						eVtimesAo = h*c/Ao/eVtoJ,	// [eV*Ang]approx:12398.134
						avogadro = 6.0221367e+23,	// Avogardo number [1/mol]
						r0 = 2.81794092e-15;		// electron radius [m]
};

#endif
