!-----------------------------------------------------------------------------
!
!						XMM Science Analysis System (SAS)
!					   (c) 1997 - 2010 European Space Agency
!
!-----------------------------------------------------------------------------
!
!	odfdesignators.f90 --- Observation Data File designators related utils
!
!   DESCRIPTION:
!       Auxiliary routines to deal with ODF designators
!
!	AUTHOR:
!		U. Lammers, Tue Jan  8 17:13:26 MET 2002
!
!	REFERENCES:
!		[1]: Software Specification Document for the XMM Science Analysis
!			 Subsystem, M. Dahlem et. al.,
!
!	$Header: /home/sasbuild/repositories/sasdev/sas/packages/caloalutils/src/odfdesignators.f90,v 1.1 2002/01/08 17:22:46 ulammers Exp $
!
module OdfDesignators
    implicit none

    interface
        !
        !   Return OdfDesignator object
        !
        function instrumentExposureIdentifier(designator) result(id)
            use CalOalDefs
            character(len=*), intent(in)                :: designator
            type(InstrumentExposureIdentifierT)         :: id
        end function

        !
        !   inquiry functions to retrieve instrument/scheduled status/exposure
        !   number from object obtained with instrumentExposureIdentifier
        !
        integer function instrument(insexpid)
            use CalOalDefs
            type(InstrumentExposureIdentifierT), intent(in)  :: insexpid
        end function

        logical function scheduleFlagApplicable(insexpid)
            use CalOalDefs
            type(InstrumentExposureIdentifierT), intent(in)  :: insexpid
        end function

        logical function scheduled(insexpid)
            use CalOalDefs
            type(InstrumentExposureIdentifierT), intent(in)  :: insexpid
        end function

        logical function unscheduled(insexpid)
            use CalOalDefs
            type(InstrumentExposureIdentifierT), intent(in)  :: insexpid
        end function

        integer function exposureNumber(insexpid)
            use CalOalDefs
            type(InstrumentExposureIdentifierT), intent(in)  :: insexpid
        end function

        !
        !   obtain expId/instrExpId string from insexpid object
        !
        character(len=4) function exposureId(insexpid)
            use CalOalDefs
            type(InstrumentExposureIdentifierT), intent(in)  :: insexpid
        end function

        character(len=6) function instrumentExposureId(insexpid)
            use CalOalDefs
            type(InstrumentExposureIdentifierT), intent(in)  :: insexpid
        end function
    end interface

end module OdfDesignators

